import { isDev } from '@/utils/tools';
import { PageContainer } from '@ant-design/pro-layout';
import { Tabs } from 'antd';
import React from 'react';
import styles from './index.less';

const { TabPane } = Tabs;
/**
 * 嵌套iframe的组件
 * @param {*} props 可在路由配置里面配置url参数
 */
const FrameContainer = props => {
  const { route } = props;
  const { url = props.url, tabs = props.tabs, tabProps = {} } = route;

  const renderedFrame = tabs ? (
    <Tabs type="card" hideAdd {...tabProps}>
      {tabs.map(({ url: iframeUrl, tabName }) => (
        <TabPane tab={tabName} key={tabName}>
          <iframe
            title={tabName}
            src={`${
              isDev ? process.env.PROXY : window.location.origin
            }${iframeUrl}`}
          />
        </TabPane>
      ))}
    </Tabs>
  ) : (
    <iframe
      title="iframe"
      src={`${isDev ? process.env.PROXY : window.location.origin}${url}`}
    />
  );

  return (
    <PageContainer
      className={styles.container}
      style={{
        display: 'flex',
        flexDirection: 'column',
        height: 'calc(100% + 24px)',
      }}
    >
      {renderedFrame}
    </PageContainer>
  );
};

export default FrameContainer;
