import React, { useState, useEffect } from 'react';
import { Checkbox } from 'antd';
import styles from './itemCard.less';

const CheckGroup = Checkbox.Group;

const ListCardItem = props => {
  const {
    getValueCallback,
    itemid,
    // userList,
    Child,
    OUName,
    searchWord,
    children,
    text,
  } = props;
  const [indeterminate, setIndeterminate] = useState(false);
  const [childValues, setChildValues] = useState({});
  const [allChecked, setAllChecked] = useState(false); // 全选状态
  const [checkList, setCheckList] = useState([]); // 复选框列表选中的值
  const [defaultList, setDefaultList] = useState([]); // 默认的选项
  const [submitArr, setSubmitArr] = useState([]); // 提交的数组
  // const submitArr = [];

  useEffect(() => {
    let arr = [];
    children.map((item, index) => {
      let obj = { ...item };
      obj.label = (
        <span
          className={
            searchWord && obj.text.includes(searchWord) ? styles.isSearch : ''
          }
        >
          {obj.text}
        </span>
      );
      obj.value = obj.userID || obj.roleID || obj.stationID || obj.id;
      arr.push(obj);
    });
    setDefaultList(arr);
  }, [searchWord]);

  useEffect(() => {
    let arr2 = [];
    children.map((item, index) => {
      if (item.isChecked) {
        arr2.push(item.userID || item.roleID || item.stationID || item.id);
      }
    });
    // eslint-disable-next-line no-unused-expressions
    getValueCallback && getValueCallback(arr2, itemid);

    const all = children.every(u => u.isChecked);
    setIndeterminate(!all && children.some(u => u.isChecked));
    setAllChecked(all);
    setCheckList(arr2);
  }, [children]);

  const handleAllChecked = e => {
    const { checked } = e.target;
    setAllChecked(checked);
    let arr = [];
    if (checked) {
      arr = defaultList.map(item => item.value);
    }
    setIndeterminate(false);
    setCheckList(arr);
    // eslint-disable-next-line no-unused-expressions
    getValueCallback && getValueCallback(arr, itemid);
  };

  const handleChecked = e => {
    setCheckList(e);
    setAllChecked(e.length === defaultList.length);
    setIndeterminate(!!e.length && e.length < defaultList.length);
    if (Child) {
      const childValArr = Object.values(childValues).flat();
      getValueCallback([...e, childValArr], itemid);
    } else {
      getValueCallback(e, itemid);
    }
  };

  const handleChildValueCallback = (arr, childIndex) => {
    childValues[childIndex] = arr;
    const childValArr = Object.values(childValues).flat();
    setChildValues({ ...childValues });
    getValueCallback([...checkList, childValArr]);
  };

  const renderChild = () =>
    Child &&
    Child.map((c, i) => (
      <ListCardItem
        {...c}
        itemid={i}
        key={`item${i}key`}
        getValueCallback={handleChildValueCallback}
        searchWord={searchWord}
      />
    ));

  if (defaultList.length === 0) {
    return null;
  }
  return (
    <>
      <div className={`${styles.divBox}`}>
        <div className={styles.topCheckbox}>
          <Checkbox
            indeterminate={indeterminate}
            checked={allChecked}
            onChange={e => {
              handleAllChecked(e);
            }}
          >
            {text}
          </Checkbox>
        </div>
        <div style={{ width: '100%' }} className={styles.checkdiv}>
          {defaultList && defaultList.length > 0 && (
            <CheckGroup
              className={styles.check}
              onChange={e => {
                handleChecked(e);
              }}
              value={checkList}
              options={defaultList}
            />
          )}
          {renderChild()}
        </div>
      </div>
    </>
  );
};

export default ListCardItem;
