import React, { useState, useEffect } from 'react';
import { Select, Card, Row, Col, Button, Spin, notification } from 'antd';
import { PageContainer } from '@ant-design/pro-layout';
import { getSolutionList, changeSolution } from '@/services/database/api';
import styles from './CurrentSolution.less';
const { Option } = Select;
const CurrentSolution = () => {
  const [currentData, setCurrentData] = useState(''); // 解决方案的值
  const [dataList, setDataList] = useState([]); // 下拉数组
  const [loading, setLoading] = useState(false);
  useEffect(() => {
    setLoading(true);
    getSolutionList({
      _version: 9999,
      _dc: new Date().getTime(),
    })
      .then(res => {
        setLoading(false);
        if (res.success) {
          setCurrentData(res.currentSolution);
          setDataList(res.solutions);
        }
      })
      .catch(err => {
        setLoading(false);
        console.error(err);
      });
  }, []);
  // 切换解决方案
  const handleSelect = e => {
    setCurrentData(e);
  };
  // 提交配置信息
  const submit = params => {
    setLoading(true);
    changeSolution({
      solution: currentData,
      _version: 9999,
      _dc: new Date().getTime(),
    })
      .then(res => {
        setLoading(false);
        if (res.success) {
          notification.success({
            message: '提示',
            description: res.message || '切换成功',
            duration: 3,
          });
        } else {
          notification.error({
            message: '提示',
            description: res.message || '切换失败',
            duration: 10,
          });
        }
      })
      .catch(err => {
        setLoading(false);
        notification.error({
          message: '提示',
          description: err,
          duration: 3,
        });
      });
  };
  return (
    <PageContainer>
      <Card className={styles.cardbox}>
        <Spin tip="Loading..." spinning={loading} className={styles.tAlign}>
          <Row>
            <Col span={2} className={styles.divbox}>
              <div>切换解决方案：</div>
            </Col>
            <Col span={21}>
              {currentData && (
                <Select
                  style={{ width: '100%' }}
                  placeholder="请切换解决方案"
                  defaultValue={currentData}
                  onChange={e => {
                    handleSelect(e);
                  }}
                >
                  {dataList &&
                    dataList.map((item, index) => (
                      <Option value={item} key={`item${index}`}>
                        {item}
                      </Option>
                    ))}
                </Select>
              )}
            </Col>
          </Row>
          <div className={styles.btnBox}>
            <Button type="primary" onClick={() => submit()}>
              提交
            </Button>
          </div>
        </Spin>
      </Card>
    </PageContainer>
  );
};

export default CurrentSolution;
