import React, { useEffect, useState } from 'react';
import {
  Card,
  Form,
  Input,
  Button,
  Select,
  Table,
  Space,
  notification,
  Modal,
  Row,
  Col,
  Popconfirm,
  Spin,
} from 'antd';
import { PageContainer } from '@ant-design/pro-layout';
import { connect } from 'react-redux';
import { get, post } from '../../services';
import {
  setTableSQLDirName,
  deleteConn,
  initDBv4,
  getInitDBLog,
  connectionTest,
} from '@/services/database/api';
import styles from './InitDataBase.less';

const { Option } = Select;
const formLables = {
  ip: '服务器名或IP地址',
  userName: '数据库用户名称',
  password: '数据库用户密码',
  dbName: '数据库名称',
};
const InitDataBase = props => {
  const [form] = Form.useForm();
  const [tableLoading, setTableLoading] = useState(false); // 连接记录
  const [dbForm, setDbForm] = useState({
    ip: '',
    dbName: '',
    password: '',
    userName: '',
    inUse: '',
  });
  const [data, setData] = useState([]); // 数据库链接记录
  const [upData, setUpData] = useState(1); // 列表刷新标记
  const [option, setOption] = useState([]); // 下拉列表数据
  const [desc, setDesc] = useState(''); // 修改描述
  const [allSqlDir, setAllSqulDir] = useState([]); // 修改产品方案
  const [defaultSqlDir, setDefaultSqlDir] = useState(''); // 修改产品方案默认值
  const [modalVisible, setModalVisible] = useState(false); // 修改秒速弹窗
  const [initVisible, setInitVisible] = useState(false); // 数据库初始化弹窗
  const [initContent, setInitContent] = useState(''); // 数据库初始化内容
  const [initLoading, setInitLoading] = useState(false);
  const [cardLoading, setCardLoading] = useState(false); // 初始化card Loading
  // 获取数据库链接记录
  useEffect(() => {
    setTableLoading(true);
    get(`/Cityinterface/rest/services/OMS.svc/S_GetConnRecord`, {
      _version: 9999,
      dc: 1603334559186,
    })
      .then(res => {
        setTableLoading(false);
        if (res.length > 0) {
          let arr = res.map((item, index) => {
            item.key = index;
            return item;
          });
          setData(arr);
        }
      })
      .catch(err => {
        setTableLoading(false);
        console.error(err);
      });
  }, [upData]);
  // 获取数据库配置信息
  useEffect(() => {
    setCardLoading(true);
    get(`/Cityinterface/rest/services/OMS.svc/S_GetDataBaseConfig`, {
      _version: 9999,
      dc: 1603334559186,
    })
      .then(res => {
        setCardLoading(false);
        if (res.success) {
          let obj = {};
          Object.keys(dbForm).forEach(k => {
            obj[k] = res[k];
          });
          form.setFieldsValue(obj);
          setDbForm(val => ({ ...val, ...obj }));
          setAllSqulDir(res.allSqlDir);
          setDefaultSqlDir(res.tableSQLDirName);
        }
      })
      .catch(err => {
        setCardLoading(false);
        console.error(err);
      });
  }, []);
  // 数据库初始化
  const initClick = () => {
    setInitLoading(true);
    let obj = form.getFieldsValue();
    initDBv4({
      _version: 9999,
      _dc: Date.now(),
      ...obj,
    })
      .then(res => {
        setInitLoading(false);
        if (res.GetMe) {
          getInitDBLog({
            _version: 9999,
            _dc: Date.now(),
          }).then(res => {
            if (res.success) {
              setInitVisible(true);
              setInitContent(res.content);
            }
            console.log(res.content.split(/[(\r\n)\r\n]+/));
          });
        } else {
          notification.error({
            message: '提示',
            duration: 3,
            description: res.Say.Message || '初始化失败',
          });
        }
      })
      .catch(err => {
        setInitLoading(false);
        console.log(err);
      });
  };
  const onValuesChange = (value, b) => {
    form.setFieldsValue(value);
  };
  const onChange = value => {
    console.log(value);
    const { length } = value;
    form.setFieldsValue({
      dbName: value[length - 1],
    });
  };
  // 保存连接
  const onFinish = values => {
    setCardLoading(true);
    const obj = values;
    get('/Cityinterface/rest/services/OMS.svc/S_SaveConnection', {
      _version: 9999,
      _dc: new Date().getTime(),
      ip: obj.ip,
      dbName: obj.dbName,
      userName: obj.userName,
      password: obj.password,
    })
      .then(res => {
        setCardLoading(false);
        if (res.GetMe === true) {
          setUpData(upData + 1);
          notification.success({
            message: '通知',
            duration: 3,
            description: '保存成功',
          });
        } else {
          notification.error({
            message: '提示',
            duration: 3,
            description: res.Say.Message || '保存失败',
          });
        }
      })
      .catch(err => {
        setCardLoading(false);
        console.log(err);
      });
  };
  // 测试连接
  const onCheck = e => {
    console.log(dbForm);
    setCardLoading(true);
    const obj = form.getFieldsValue();
    get('/Cityinterface/rest/services/OMS.svc/S_GetConnectionTest', {
      _version: 9999,
      _dc: new Date().getTime(),
      ip: obj.ip,
      dbName: obj.dbName,
      userName: obj.userName,
      password: obj.password,
    })
      .then(res => {
        setCardLoading(false);
        if (res.GetMe === true) {
          notification.success({
            message: '通知',
            duration: 3,
            description: '连接成功',
          });
        } else {
          notification.error({
            message: '提示',
            duration: 3,
            description: res.Say.Message || '连接失败',
          });
        }
      })
      .catch(err => {
        setCardLoading(false);
        console.log(err);
        notification.error({
          message: '提示',
          duration: 3,
          description: err || '连接失败',
        });
      });
  };
  const selectFocus = e => {
    setOption([]);
    let params = form.getFieldsValue();
    get(`/Cityinterface/rest/services/OMS.svc/S_GetDataBaseList`, {
      _version: 9999,
      _dc: 1603334559186,
      userName: params.userName || '',
      password: params.password || '',
      ip: params.ip || '',
    })
      .then(res => {
        if (res.success) {
          setOption(res.root);
        } else {
          notification.error({
            message: '通知',
            duration: 3,
            description: res.message,
          });
          setOption([]);
        }
        console.log(res);
      })
      .catch(err => {
        console.error(err);
      });
  };
  // 点击表格回显到表单
  const tableClick = item => {
    console.log(item);
    let obj = { ...dbForm };
    Object.keys(obj).forEach(k => {
      obj[k] = item[k];
    });
    form.setFieldsValue(obj);
  };
  // 产品方案选择框回调
  const handleSelect = value => {
    setTableSQLDirName({
      dirName: value,
      _version: 9999,
      _dc: new Date().getTime(),
    })
      .then(res => {
        if (res.success) {
          notification.success({
            message: '提示',
            duration: 3,
            description: `已切换初始化脚本为:${value}`,
          });
        } else {
          notification.error({
            message: '提示',
            duration: 3,
            description: res.message,
          });
        }
      })
      .catch(err => {
        console.error(err);
      });
  };
  // 展示修改描述
  const changeDesc = val => {
    console.log(val);
    setDesc(val);
    setModalVisible(true);
  };
  const descChange = e => {
    const { value } = e.target;
    setDesc(value);
  };
  // 弹窗确认回调
  const modalOkCallback = () => {
    console.log(form.getFieldsValue());
    const obj = form.getFieldsValue();
    // 更新描述
    get('/Cityinterface/rest/services/OMS.svc/S_UpdateConnDesc', {
      _version: 9999,
      _dc: new Date().getTime(),
      ip: obj.ip,
      dbName: obj.dbName,
      userName: obj.userName,
      password: obj.password,
      desc,
    })
      .then(res => {
        console.log(res);
        setModalVisible(false);
        setUpData(upData + 1);
      })
      .catch(err => {
        console.error(err);
        setModalVisible(false);
      });
  };
  // 删除数据库连接记录
  const delConfirm = value => {
    const { key = '' } = value;
    setTableLoading(true);
    deleteConn({
      rowIndex: key,
      _version: 9999,
      _dc: new Date().getTime(),
    })
      .then(res => {
        setTableLoading(false);
        if (res.success) {
          setUpData(upData + 1);
          notification.success({
            message: '提示',
            duration: 3,
            description: '操作成功',
          });
        } else {
          notification.error({
            message: '提示',
            duration: 3,
            description: res.message,
          });
        }
      })
      .catch(err => {
        setTableLoading(false);
        console.error(err);
      });
  };
  const columns = [
    {
      title: '服务器名或IP地址',
      dataIndex: 'ip',
      key: 'ip',
    },
    {
      title: '数据库名称',
      dataIndex: 'dbName',
      key: 'dbName',
    },
    {
      title: '数据库用户名称',
      dataIndex: 'userName',
      key: 'userName',
    },
    {
      title: '保存时间',
      dataIndex: 'saveTime',
      key: 'saveTime',
    },
    {
      title: '描述',
      dataIndex: 'desc',
      key: 'desc',
    },
    {
      title: '操作',
      dataIndex: 'action',
      key: 'action',
      render: (text, record) => (
        <Space>
          <Button
            type="primary"
            size="small"
            onClick={() => {
              changeDesc(record.desc);
            }}
          >
            修改描述
          </Button>
          <Popconfirm
            title="是否删除该连接的历史记录？"
            okText="确认"
            cancelText="取消"
            onConfirm={() => {
              delConfirm(record);
            }}
          >
            <Button size="small" danger>
              删除
            </Button>
          </Popconfirm>
        </Space>
      ),
    },
  ];
  return (
    <>
      <PageContainer>
        <Card>
          <Spin tip="loading..." spinning={cardLoading}>
            <div className={styles.tableTitle}>数据库初始化</div>
            <Form
              className={styles.mgTop20}
              layout="horizontal"
              labelAlign="left"
              labelCol={{ span: 3 }}
              form={form}
              onFinish={onFinish}
              onValuesChange={onValuesChange}
            >
              <Form.Item label={`${formLables.ip}：`} name="ip">
                <Input placeholder="请输入服务器名或IP地址" />
              </Form.Item>
              <Form.Item label={`${formLables.userName}：`} name="userName">
                <Input placeholder="请输入用户名称" />
              </Form.Item>
              <Form.Item label={`${formLables.password}：`} name="password">
                <Input placeholder="请输入用户密码" />
              </Form.Item>
              <Form.Item label={`${formLables.dbName}：`} name="dbName">
                <Select
                  showSearch
                  mode="tags"
                  placeholder="请选择数据库"
                  optionFilterProp="children"
                  onFocus={() => {
                    selectFocus();
                  }}
                  onChange={e => {
                    onChange(e);
                  }}
                  // eslint-disable-next-line no-shadow
                  filterOption={(input, option) => {
                    console.log(option);
                    return (
                      option.children &&
                      option.children
                        .toLowerCase()
                        .indexOf(input.toLowerCase()) >= 0
                    );
                  }}
                >
                  {option &&
                    option.length > 0 &&
                    option.map((item, index) => (
                      <Option value={item.value} key={item.value + index}>
                        {item.value}
                      </Option>
                    ))}
                </Select>
              </Form.Item>
              <Form.Item>
                <div className={styles.tCenter}>
                  <Space size="large" className={styles.btnBox}>
                    <Space>
                      <Button onClick={onCheck}>测试连接</Button>
                      <Button
                        type="primary"
                        htmlType="submit"
                        loading={tableLoading}
                      >
                        保存连接
                      </Button>
                    </Space>
                    <Space>
                      <Popconfirm
                        title="是否执行数据库初始化"
                        okText="确认"
                        cancelText="取消"
                        onConfirm={() => {
                          initClick();
                        }}
                      >
                        <Button type="primary" loading={initLoading}>
                          数据库初始化
                        </Button>
                      </Popconfirm>
                      {defaultSqlDir && (
                        <Select
                          placeholder="请选择解决方案"
                          style={{ width: '200px' }}
                          defaultValue={defaultSqlDir}
                          onChange={e => {
                            handleSelect(e);
                          }}
                        >
                          {allSqlDir &&
                            allSqlDir.map((item, index) => (
                              <Option value={item} key={index}>
                                {item}
                              </Option>
                            ))}
                        </Select>
                      )}
                    </Space>
                  </Space>
                </div>
              </Form.Item>
            </Form>
          </Spin>
        </Card>

        <Card className={styles.mgTop20}>
          <div className={styles.tableTitle}>近期保存的数据库连接</div>
          <Table
            style={{ marginTop: '20px' }}
            columns={columns}
            dataSource={data}
            bordered
            loading={tableLoading}
            size="small"
            onRow={record => ({
              onClick: () => {
                tableClick(record);
              }, // 点击行
            })}
          />
        </Card>
        <Modal
          title="初始化数据库"
          visible={initVisible}
          onCancel={() => {
            setInitVisible(false);
            setInitContent('');
          }}
          width="800px"
          bodyStyle={{
            maxHeight: '600px',
            overflowY: 'scroll',
          }}
          footer={[
            <Button
              onClick={() => {
                setInitVisible(false);
                setInitContent('');
              }}
              type="primary"
            >
              关闭窗口
            </Button>,
          ]}
        >
          {initContent}
        </Modal>

        <Modal
          title="修改链接描述"
          visible={modalVisible}
          onOk={() => modalOkCallback()}
          onCancel={() => setModalVisible(false)}
          width="800px"
          bodyStyle={{
            minHeight: '100px',
          }}
          cancelText="取消"
          okText="确认修改"
          destroyOnClose
        >
          <Row>
            <Col span={2} className={styles.decsBox}>
              描述：
            </Col>
            <Col span={22}>
              <Input
                placeholder="请输入描述"
                allowClear
                defaultValue={desc}
                onChange={value => {
                  descChange(value);
                }}
              />
            </Col>
          </Row>
        </Modal>
      </PageContainer>
    </>
  );
};

export default connect()(InitDataBase);
