import React, { useState, useEffect } from 'react';
import { Form, Select, Input, Button, Radio, notification } from 'antd';
import { editWebsite, getWebsite } from '@/services/mobileConfig/api';
import PicturesWall from '@/components/Upload/index';

const { Item } = Form;
const { Option } = Select;
const SiteConfig = props => {
  const { miniTitle } = props;
  const [config, setConfig] = useState(''); // 网站配置信息
  const [loginList, setLoginList] = useState([
    { text: '默认界面', value: 'default' },
  ]); // 系统登陆页
  const [styleList, setStyleList] = useState([
    { text: '默认风格', value: 'default' },
  ]); // 系统风格
  const [themeList, setThemeList] = useState([
    { text: '默认皮肤', value: 'default' },
  ]); // 系统皮肤

  const [form] = Form.useForm();
  const layout = {
    layout: 'horizontal',
    labelCol: { span: 3 },
    wrapperCol: { span: 14 },
  };
  useEffect(() => {
    if (!miniTitle) {
      return;
    }
    getWebsite({
      _version: 9999,
      _dc: Date.now(),
      title: miniTitle,
    }).then(res => {
      let obj = { ...form.getFieldsValue() };
      let arr = Object.keys({ ...form.getFieldsValue() });
      arr.map(k => {
        obj[k] = res[k];
      });
      form.setFieldsValue(obj);
    });
  }, [miniTitle]);
  // 单选值改变
  const radioChange = e => {};
  // 提交选择
  const submit = value => {
    form.validateFields().then(valid => {
      if (valid) {
        const obj = { ...form.getFieldsValue() };
        let params = { ...obj, mode: 'single', client: 'miniapp' };
        editWebsite(params, {
          headers: {
            'content-type': 'application/x-www-form-urlencggoded;charset=UTF-8',
          },
        }).then(res => {
          if (res.success) {
            notification.success({
              message: '提示',
              duration: 3,
              description: '编辑成功',
            });
          } else {
            notification.error({
              message: '提示',
              duration: 3,
              description: res.message || '编辑失败',
            });
          }
          console.log(res, 'res');
        });
      }
    });
  };
  return (
    <Form form={form} {...layout}>
      <Item
        label="应用名称："
        name="title"
        rules={[
          {
            required: true,
            message: '请输入应用名称',
          },
        ]}
      >
        <Input placeholder="请输入应用名称" allowClear />
      </Item>

      <Item
        label="系统图标："
        name="shortcutIcon"
        rules={[
          {
            required: true,
            message: '请选择系统图标',
          },
        ]}
      >
        <Input placeholder="请输入系统图标名称" allowClear />
      </Item>

      <Item label="系统图标预览：">
        <PicturesWall />
      </Item>
      <Item
        label="登陆页面："
        name="loginTemplate"
        rules={[
          {
            required: true,
            message: '请选择登陆页面',
          },
        ]}
      >
        <Select placeholder="请选择登陆页面">
          {loginList &&
            loginList.map((item, index) => (
              <Option value={item.value} key={`item${index}`}>
                {item.text}
              </Option>
            ))}
        </Select>
      </Item>
      <Item
        label="系统皮肤："
        name="theme"
        rules={[
          {
            required: true,
            message: '请选择系统皮肤',
          },
        ]}
      >
        <Select placeholder="请选择系统皮肤">
          {themeList &&
            themeList.map((item, index) => (
              <Option value={item.value} key={`item${index}`}>
                {item.text}
              </Option>
            ))}
        </Select>
      </Item>
      <Item
        label="系统风格："
        name="style"
        rules={[
          {
            required: true,
            message: '请选择系统风格',
          },
        ]}
      >
        <Select placeholder="请选择系统风格">
          {styleList &&
            styleList.map((item, index) => (
              <Option value={item.value} key={`item${index}`}>
                {item.text}
              </Option>
            ))}
        </Select>
      </Item>
      <Item label="开启云登陆：" name="cloudLogin">
        <Radio.Group onChange={radioChange}>
          <Radio value>是</Radio>
          <Radio value={false}>否</Radio>
        </Radio.Group>
      </Item>
      <Item style={{ textAlign: 'center' }}>
        <Button type="primary" onClick={submit}>
          提交
        </Button>
      </Item>
    </Form>
  );
};
export default SiteConfig;
