import React, { useState, useEffect, useCallback } from 'react';
import {
  Tree,
  Table,
  Space,
  message,
  Modal,
  Form,
  Input,
  notification,
  Tooltip,
  Row,
  Col,
  Divider,
  Tabs,
  Checkbox,
  Button,
  Spin,
} from 'antd';
import {
  FileAddTwoTone,
  FolderAddTwoTone,
  EditTwoTone,
  DeleteTwoTone,
  ShareAltOutlined,
  UnlockOutlined,
  ApartmentOutlined,
  SearchOutlined,
  StopOutlined,
  FolderOpenOutlined,
  FileOutlined,
} from '@ant-design/icons';
import { PageContainer } from '@ant-design/pro-layout';
// import classnames from 'classnames';
// import { get } from '../../services';
import styles from './UserManage.less';
import ListCardItem from '../orgnazation/listCardItem';
import {
  addToOrg,
  editOrgInfo,
  getOneOUUserListNew,
  getUserByKey,
  getUserRelationList,
  getUserTree,
  addUser as postAddUser,
  deleteUser as postDeleteUser,
  setUserState as postSetUserState,
  editUser as postEditUser,
  submitAddOrg as postAddOrg,
  deleteOrg as postDeleteOrg,
  updateUserPassword,
  setUserRelation,
} from '@/services/userCenter/userManage/api';

const UserManage = () => {
  const [treeLoading, setTreeLoading] = useState(true);
  const [tableLoading, setTableLoading] = useState(false);
  const [loading, setLoading] = useState(true);

  const [treeData, setTreeData] = useState([]); // 用户机构树
  const [treeData1, setTreeData1] = useState([]); // 用户机构树-备份，供更改机构使用
  const [treeData2, setTreeData2] = useState([]);
  const [tableData, setTableData] = useState([]); // 用户表
  const [searchData, setSearchData] = useState([]);
  const [currentSelectOrg, setCurrentSelectOrg] = useState([]);

  const [userVisible, setUserVisible] = useState(false);
  const [searchUserVisible, setSearchUserVisible] = useState(false);
  const [addOrgVisible, setAddOrgVisible] = useState(false);
  const [editOrgVisible, setEditOrgVisible] = useState(false);
  const [deleteOrgVisible, setDeleteOrgVisible] = useState(false);
  const [roleVisible, setRoleVisible] = useState(false);
  const [changeOrgVisible, setChangeOrgVisible] = useState(false);
  const [passwordVisible, setPasswordVisible] = useState(false);
  const [editUserVisible, setEditUserVisible] = useState(false);
  const [treeState, setTreeState] = useState(true);
  const [freezeUserVisible, setFreezeUserVisible] = useState(false);
  const [deleteUserVisible, setDeleteUserVisible] = useState(false);

  const [orgTitle, setOrgTitle] = useState('机构');
  const [tableTitle, setTableTitle] = useState('机构');
  const [orgID, setOrgID] = useState();
  const [newOrgID, setNewOrgID] = useState();
  const [currentUser, setCurrentUser] = useState({});
  const [rolelist, setRolelist] = useState([]);
  const [stationlist, setStationlist] = useState([]);

  const [roleValueList, setRoleValueList] = useState({});
  const [stationValueList, setStationValueList] = useState({});

  const [searchUserForm] = Form.useForm();
  const [addUserForm] = Form.useForm();
  const [addOrgForm] = Form.useForm();
  const [editOrgForm] = Form.useForm();
  const [editUserForm] = Form.useForm();
  const [passwordForm] = Form.useForm();
  const { TabPane } = Tabs;

  const getRoleValueCallback = useCallback((value, index) => {
    roleValueList[index] = value;
    setRoleValueList({ ...roleValueList });
  }, []);

  const getStationValueCallback = useCallback((value, index) => {
    stationValueList[index] = value;
    setStationValueList({ ...stationValueList });
  }, []);

  // 用户表列名
  const columns = [
    {
      title: '登录名',
      dataIndex: 'loginName',
      key: 'loginName',
      fixed: 'left',
      width: 100,
    },
    {
      title: '用户姓名',
      dataIndex: 'userName',
      key: 'userName',
      width: 100,
    },
    {
      title: '所在机构',
      dataIndex: 'OUName',
      key: 'OUName',
      width: 150,
    },
    {
      title: '手机号码',
      dataIndex: 'phone',
      key: 'phone',
      width: 150,
      ellipsis: true,
    },
    {
      title: '钉钉账户',
      dataIndex: 'ddid',
      key: 'ddid',
      width: 150,
    },
    {
      title: '微信账户',
      dataIndex: 'wxid',
      key: 'wxid',
      width: 150,
    },
    {
      title: '操作',
      key: 'action',
      fixed: 'right',
      width: 250,
      align: 'center',
      render: (text, record) => (
        <Space size="middle">
          <Tooltip title="关联角色">
            <ShareAltOutlined
              onClick={() => relateRole(record)}
              style={{ fontSize: '16px', color: '#1890FF' }}
            />
          </Tooltip>
          <Tooltip title="更改机构">
            <ApartmentOutlined
              onClick={() => changeOrg(record)}
              style={{ fontSize: '16px', color: '#1890FF' }}
            />
          </Tooltip>
          <Tooltip title="修改密码">
            <UnlockOutlined
              onClick={() => changePassword(record)}
              style={{ fontSize: '16px', color: '#1890FF' }}
            />
          </Tooltip>
          <Tooltip title="编辑用户">
            <EditTwoTone
              onClick={() => editUser(record)}
              style={{ fontSize: '16px' }}
            />
          </Tooltip>

          {(record.state === '0' || record.state === null) && (
            <>
              <Tooltip title="冻结用户">
                <StopOutlined
                  onClick={() => freezeUser(record)}
                  style={{ fontSize: '16px', color: '#1890FF' }}
                />
              </Tooltip>
            </>
          )}
          {record.state === '1' && (
            <>
              <Tooltip title="解冻用户">
                <StopOutlined
                  onClick={() => freezeUser(record)}
                  style={{ fontSize: '16px' }}
                />
              </Tooltip>
            </>
          )}
          <Tooltip title="删除用户">
            <DeleteTwoTone
              onClick={() => deleteUser(record)}
              style={{ fontSize: '16px' }}
            />
          </Tooltip>
        </Space>
      ),
    },
  ];
  const searchColumns = [
    {
      title: '所在机构',
      dataIndex: 'OUName',
      key: 'OUName',
    },
    {
      title: '登录名称',
      dataIndex: 'loginName',
      key: 'loginName',
      render: item => (
        <div
          ref={r => {
            if (r) {
              r.innerHTML = item;
            }
          }}
        />
      ),
    },
    {
      title: '用户姓名',
      dataIndex: 'userName',
      key: 'userName',
      render: item => (
        <div
          ref={r => {
            if (r) {
              r.innerHTML = item;
            }
          }}
        />
      ),
    },
    {
      title: '手机号码',
      dataIndex: 'phone',
      key: 'phone',
    },
  ];

  // 渲染机构树
  const mapTree = org => {
    const haveChildren = Array.isArray(org.children) && org.children.length > 0;
    return {
      title: (
        <>
          <span>{org.text}</span>
          <div className={styles.iconWraper1}>
            <Tooltip title="添加用户">
              <FileAddTwoTone onClick={e => addUser(e, org.text, org.id)} />
            </Tooltip>
            <Tooltip title="添加下级机构">
              <FolderAddTwoTone onClick={e => addSubOrg(e, org.text, org.id)} />
            </Tooltip>
            <Tooltip title="编辑当前机构">
              <EditTwoTone onClick={e => editOrg(e, org.text, org.id)} />
            </Tooltip>
            <Tooltip title="删除当前机构">
              <DeleteTwoTone onClick={e => deleteOrg(e, org.text, org.id)} />
            </Tooltip>
          </div>
        </>
      ),
      key: org.id,
      // icon: org.leaf ? <FileOutlined /> : <FolderOpenOutlined />,
      // 判断它是否存在子集，若果存在就进行再次进行遍历操作，知道不存在子集便对其他的元素进行操作
      children: haveChildren ? org.children.map(i => mapTree(i)) : [],
    };
  };
  const mapTree1 = org => {
    const haveChildren = Array.isArray(org.children) && org.children.length > 0;
    return {
      title: `${org.text}`,
      key: org.id,
      // icon: org.leaf ? <FileOutlined /> : <FolderOpenOutlined />,
      // 判断它是否存在子集，若果存在就进行再次进行遍历操作，知道不存在子集便对其他的元素进行操作
      children: haveChildren ? org.children.map(i => mapTree1(i)) : [],
    };
  };

  const updateTrees = () => {
    setTreeLoading(true);
    getUserTree(-1, -1)
      .then(res => {
        if (res.length > 0) {
          setTreeLoading(false);
          setTreeData1(res);
          setTreeData(res);
          // 第一次加载，默认选择第一个组织
          if (treeState) {
            onSelect([res[0].id]);
            setTreeState(false);
          }
        }
      })
      .catch(err => {
        setTreeLoading(false);
        message.error(err);
      });
  };

  // 获取用户机构树
  useEffect(() => {
    setTreeLoading(true);
    updateTrees();
  }, []);

  // 获取当前机构下所有用户
  const onSelect = props => {
    setTableLoading(true);
    if (!props[0]) {
      setCurrentSelectOrg(currentSelectOrg);
    } else {
      setCurrentSelectOrg(props[0]);
    }
    setOrgID(props[0] || currentSelectOrg);
    getOneOUUserListNew(props[0] || currentSelectOrg)
      .then(res => {
        if (res.IsSuccess) {
          setTableLoading(false);
          const temp = flatten(getUsers(res.Data));
          console.log(temp);
          setTableTitle(temp.length);
          const table = temp.map((item, index) => {
            item.key = index;
            item.phone = item.phone || '-';
            item.ddid = item.ddid ? '已绑定' : '未绑定';
            item.wxid = item.wxid ? '已绑定' : '未绑定';
            return item;
          });
          setTableData(table);
        }
      })
      .catch(err => {
        setTableLoading(false);
        message.error(err);
      });
  };
  // 返回数据结构处理，扁平化
  const getUsers = orgObj => {
    let result = orgObj.Users;
    result.map(item => {
      item.OUID = orgObj.GroupId;
      item.OUName = orgObj.GroupName;
      return item;
    });
    if (orgObj.Childs.length > 0)
      result = [...result, ...orgObj.Childs.map(o => getUsers(o))];
    return result;
  };
  const flatten = arr => {
    while (arr.some(item => Array.isArray(item))) {
      arr = [].concat(...arr);
    }
    return arr;
  };
  const getTableTitle = () => `当前机构用户总数（ ${tableTitle} ）`;
  // 左侧目录树相关操作
  const searchUser = () => {
    setSearchUserVisible(true);
  };
  const addUser = (e, title, id) => {
    // e.stopPropagation();
    setUserVisible(true);
    setOrgTitle(`在${title}下添加用户`);
    setOrgID(id);
  };
  const addSubOrg = (e, title, id) => {
    // e.stopPropagation();
    setAddOrgVisible(true);
    setOrgTitle(`在${title}下添加机构`);
    setOrgID(id);
  };
  const editOrg = (e, title, id) => {
    // e.stopPropagation();
    setEditOrgVisible(true);
    editOrgForm.setFieldsValue({
      OUName: title,
    });
    setOrgID(id);
  };
  const deleteOrg = (e, title, id) => {
    // e.stopPropagation();
    setDeleteOrgVisible(true);
    setOrgTitle(`删除组织${title}`);
    setOrgID(id);
    // 删除后默认选择第一个组织
    setTreeState(true);
  };

  // 在currentUser变化后获取
  useEffect(() => {
    if (currentUser && currentUser.userID) {
      getRoleList();
    }
  }, [currentUser]);

  // 右侧表格相关操作
  const relateRole = record => {
    setRoleVisible(true);
    setCurrentUser(record);
  };

  const changeOrg = record => {
    setChangeOrgVisible(true);
    setTreeData2(treeData1);
    setCurrentUser(record);
  };

  const changePassword = record => {
    setPasswordVisible(true);
    passwordForm.setFieldsValue({
      oldpassword: record.password,
    });
    setCurrentUser(record);
  };

  const editUser = record => {
    // console.log(record);
    setEditUserVisible(true);
    editUserForm.setFieldsValue({
      loginName: record.loginName,
      userName: record.userName,
      phone: record.phone || '',
      email: record.email || '',
    });
    setCurrentUser(record);
  };

  const freezeUser = record => {
    setFreezeUserVisible(true);
    setCurrentUser(record);
  };

  const deleteUser = record => {
    setDeleteUserVisible(true);
    setCurrentUser(record);
  };

  // 查找用户
  const submitSearchUser = () => {
    getUserByKey(searchUserForm.getFieldValue('key'))
      .then(res => {
        if (res.success) {
          // setSearchUserVisible(false);
          setSearchData(res.root);
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        message.error(err);
      });
  };

  // 提交-添加用户
  const submitAddUser = () => {
    postAddUser({
      OUID: orgID,
      loginName: addUserForm.getFieldValue('loginName'),
      userName: addUserForm.getFieldValue('userName'),
      password: addUserForm.getFieldValue('password'),
      phone: addUserForm.getFieldValue('phone') || '',
      email: addUserForm.getFieldValue('email') || '',
    })
      .then(res => {
        if (res.success) {
          setUserVisible(false);
          notification.success({
            message: '提交成功',
          });
          // 重新获取用户表
          onSelect([orgID]);
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        message.error(err);
      });
  };

  // 提交-添加下级机构
  const submitAddOrg = () => {
    postAddOrg(
      orgID,
      addOrgForm.getFieldValue('OUName'),
      addOrgForm.getFieldValue('desrciption') || '',
      '',
    )
      .then(res => {
        if (res.success) {
          setAddOrgVisible(false);
          notification.success({
            message: '提交成功',
          });
          // 重新获取机构树与用户表
          updateTrees().then(() => {
            // 只能是字符串，数字没有选择效果
            onSelect([`${res.OUID}`]);
          });
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        message.error(err);
      });
  };

  // 提交-编辑当前机构
  const submitEditOrg = () =>
    editOrgInfo(
      orgID,
      editOrgForm.getFieldValue('OUName'),
      editOrgForm.getFieldValue('desrciption') || '',
      '',
    )
      .then(res => {
        if (res.success) {
          setEditOrgVisible(false);
          notification.success({
            message: '提交成功',
          });
          // 重新获取机构树与用户表
          updateTrees();
          onSelect([orgID]);
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        message.error(err);
      });

  // 提交删除机构
  const submitDeleteOrg = () =>
    postDeleteOrg(orgID)
      .then(res => {
        if (res.success) {
          setDeleteOrgVisible(false);
          notification.success({
            message: '提交成功',
          });
          // 重新获取机构树与用户表
          updateTrees();
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        setTableLoading(false);
        message.error(err);
      });

  const getRoleList = () => {
    setLoading(true);
    getUserRelationList(currentUser.userID)
      .then(res => {
        setLoading(false);
        if (res.success) {
          const { roleList, stationList } = res;
          setRolelist(roleList);
          setStationlist(stationList);
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        setLoading(false);
        setTableLoading(false);
        message.error(err);
      });
  };
  const submitRole = () => {
    setUserRelation(
      currentUser.userID,
      Object.keys(roleValueList)
        .map(k => roleValueList[k])
        .flat(),
      Object.keys(stationValueList)
        .map(k => stationValueList[k])
        .flat(),
    )
      .then(res => {
        if (res.success) {
          setRoleVisible(false);
          // 跳转到新组织机构下的用户表
          onSelect([newOrgID]);
          notification.success({
            message: '提交成功',
          });
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        message.error(err);
      });
  };
  const submitChangeOrg = () =>
    addToOrg(currentUser.userID, currentUser.OUID, newOrgID)
      .then(res => {
        if (res.success) {
          setChangeOrgVisible(false);
          // 跳转到新组织机构下的用户表
          onSelect([newOrgID]);
          notification.success({
            message: '提交成功',
          });
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        message.error(err);
      });
  const submitChangePassword = () =>
    updateUserPassword(
      currentUser.userID,
      passwordForm.getFieldValue('password'),
      passwordForm.getFieldValue('newPassword'),
      passwordForm.getFieldValue('passwordConfirm'),
    )
      .then(res => {
        if (res.success) {
          setPasswordVisible(false);
          // 重新获取用户表
          onSelect([orgID]);
          notification.success({
            message: '提交成功',
          });
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        message.error(err);
      });
  const submitEditUser = () =>
    postEditUser(
      currentUser.userID,
      editUserForm.getFieldValue('loginName'),
      editUserForm.getFieldValue('userName'),
      editUserForm.getFieldValue('phone') || '',
      editUserForm.getFieldValue('email') || '',
    )
      .then(res => {
        if (res.success) {
          setEditUserVisible(false);
          // 重新获取用户表
          onSelect([orgID]);
          notification.success({
            message: '提交成功',
          });
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        setTableLoading(false);
        message.error(err);
      });
  const submitFreezeUser = () => {
    let state = '';
    if (currentUser.state === '0') {
      state = '1';
    } else {
      state = '0';
    }
    postSetUserState(currentUser.userID, state)
      .then(res => {
        if (res.success) {
          setFreezeUserVisible(false);
          // 重新获取用户表
          onSelect([orgID]);
          notification.success({
            message: '提交成功',
          });
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        setTableLoading(false);
        message.error(err);
      });
  };
  const submitDeleteUser = () => {
    postDeleteUser(currentUser.userID)
      .then(res => {
        if (res.success) {
          setDeleteUserVisible(false);
          notification.success({
            message: '提交成功',
          });
          // 重新获取用户表
          onSelect([orgID]);
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        setTableLoading(false);
        message.error(err);
      });
  };

  return (
    <PageContainer className={styles.userManageContainer}>
      <div className={styles.contentContainer}>
        <div className={styles.orgContainer}>
          <span style={{ padding: '8px', fontSize: '16px' }}>
            机构列表
            <Tooltip title="查找用户">
              <SearchOutlined
                style={{
                  fontSize: '18px',
                  float: 'right',
                  margin: '4px 4px 0px 12px',
                  color: '#1890FF',
                }}
                onClick={searchUser}
              />
            </Tooltip>
            <Tooltip title="添加下级机构">
              <FolderAddTwoTone
                style={{
                  fontSize: '18px',
                  float: 'right',
                  marginTop: '4px',
                }}
                onClick={e => addSubOrg(e, '根目录', '-1')}
              />
            </Tooltip>
          </span>
          {treeData.length > 0 && (
            <Spin spinning={treeLoading} tip="loading...">
              <Tree
                // showLine="true"
                showIcon="true"
                showLine={{ showLeafIcon: false }}
                defaultExpandAll="true"
                selectedKeys={[currentSelectOrg]}
                onSelect={onSelect}
                treeData={treeData.map(t => mapTree(t))}
              />
            </Spin>
          )}
        </div>
        <div className={styles.userContainer}>
          <Table
            title={getTableTitle}
            bordered
            columns={columns}
            dataSource={tableData}
            loading={tableLoading}
            scroll={{ scrollToFirstRowOnChange: 'true', x: 'max-content' }}
          />
        </div>
        {/* 查找用户 */}
        <Modal
          title="查找用户"
          visible={searchUserVisible}
          onCancel={() => setSearchUserVisible(false)}
          footer={[
            <Button
              key="back"
              type="primary"
              onClick={() => setSearchUserVisible(false)}
            >
              关闭
            </Button>,
          ]}
        >
          <Form form={searchUserForm}>
            <Form.Item
              name="key"
              label="关键字搜索"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input
                placeholder="请输入登录名称/用户名称/手机号 ，回车键查找"
                onPressEnter={submitSearchUser}
              />
            </Form.Item>
          </Form>
          <Table
            bordered
            columns={searchColumns}
            dataSource={searchData}
            onRow={record => ({
              onClick: () => {
                onSelect([record.OUID]);
                setSearchUserVisible(false);
              },
            })}
          />
        </Modal>
        {/* 添加用户 */}
        <Modal
          title={orgTitle}
          visible={userVisible}
          onOk={submitAddUser}
          onCancel={() => setUserVisible(false)}
          okText="确认"
          cancelText="取消"
        >
          <Form form={addUserForm} labelCol={{ span: 4 }}>
            <Form.Item
              name="loginName"
              label="登录名称"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="请输入登录名称" />
            </Form.Item>
            <Form.Item
              name="password"
              label="账户密码"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="请输入账户密码" />
            </Form.Item>
            <Form.Item
              name="userName"
              label="用户名称"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="请输入用户姓名" />
            </Form.Item>
            <Form.Item name="phone" label="手机号码">
              <Input placeholder="请输入手机号码" />
            </Form.Item>
            <Form.Item name="email" label="电子邮箱">
              <Input placeholder="请输入电子邮箱" />
            </Form.Item>
          </Form>
        </Modal>
        {/* 添加下级机构 */}
        <Modal
          title={orgTitle}
          visible={addOrgVisible}
          onOk={submitAddOrg}
          onCancel={() => setAddOrgVisible(false)}
          okText="确认"
          cancelText="取消"
        >
          <Form form={addOrgForm} labelCol={{ span: 4 }}>
            <Form.Item
              name="OUName"
              label="机构名称"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="请输入机构名称" />
            </Form.Item>
            <Form.Item name="description" label="描述">
              <Input placeholder="请输入相关描述" />
            </Form.Item>
          </Form>
        </Modal>
        {/* 编辑机构 */}
        <Modal
          title={orgTitle}
          visible={editOrgVisible}
          onOk={submitEditOrg}
          onCancel={() => setEditOrgVisible(false)}
          okText="确认"
          cancelText="取消"
        >
          <Form form={editOrgForm} labelCol={{ span: 4 }}>
            <Form.Item
              name="OUName"
              label="机构名称"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="请输入机构名称" />
            </Form.Item>
            <Form.Item name="description" label="描述">
              <Input placeholder="请输入相关描述" />
            </Form.Item>
          </Form>
        </Modal>
        <Modal
          title="确认删除机构"
          visible={deleteOrgVisible}
          onOk={submitDeleteOrg}
          onCancel={() => setDeleteOrgVisible(false)}
          okText="确认"
          cancelText="取消"
        >
          <p>即将删除该机构，是否确认删除？</p>
        </Modal>
        <Modal
          title="用户关联"
          visible={roleVisible}
          onOk={submitRole}
          onCancel={() => setRoleVisible(false)}
          okText="确认"
          cancelText="取消"
          width="960px"
        >
          <Spin spinning={loading} tip="loading">
            <Tabs defaultActiveKey="1">
              <TabPane tab="角色" key="1">
                {roleVisible &&
                  rolelist.map((role, index) => (
                    <ListCardItem
                      itemid={index}
                      key={`item${index}key`}
                      userList={role.roleList}
                      OUName={role.visibleTitle}
                      getValueCallback={getRoleValueCallback}
                    />
                  ))}
              </TabPane>
              <TabPane tab="站点" key="2">
                {roleVisible &&
                  stationlist.map((station, index) => (
                    <ListCardItem
                      itemid={index}
                      key={`item${index}key`}
                      userList={station.stationList}
                      OUName={station.visibleTitle}
                      getValueCallback={getStationValueCallback}
                    />
                  ))}
              </TabPane>
            </Tabs>
          </Spin>
        </Modal>
        <Modal
          title="更改机构"
          visible={changeOrgVisible}
          onOk={submitChangeOrg}
          onCancel={() => setChangeOrgVisible(false)}
          okText="确认"
          cancelText="取消"
          width="330px"
        >
          <span>请选择要更改的目标机构：</span>
          {changeOrgVisible && treeData2.length > 0 && (
            <Tree
              showIcon="true"
              showLine={{ showLeafIcon: false }}
              defaultExpandAll="true"
              defaultSelectedKeys={[currentSelectOrg]}
              onSelect={props => {
                setNewOrgID(props[0]);
              }}
              treeData={treeData2.map(t => mapTree1(t))}
            />
          )}
        </Modal>
        {/* 修改密码 */}
        <Modal
          title="修改密码"
          visible={passwordVisible}
          onOk={submitChangePassword}
          onCancel={() => setPasswordVisible(false)}
          okText="确认"
          cancelText="取消"
        >
          <Form form={passwordForm} labelCol={{ span: 4 }}>
            <Form.Item name="oldpassword" label="原始密码">
              <Input disabled />
            </Form.Item>
            <Form.Item
              name="newPassword"
              label="新密码"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="请输入新密码" />
            </Form.Item>
            <Form.Item
              name="passwordConfirm"
              label="确认密码"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="再次确认新密码" />
            </Form.Item>
          </Form>
        </Modal>
        {/* 编辑用户 */}
        <Modal
          title="编辑用户"
          visible={editUserVisible}
          onOk={submitEditUser}
          onCancel={() => setEditUserVisible(false)}
          okText="确认"
          cancelText="取消"
        >
          <Form form={editUserForm} labelCol={{ span: 4 }}>
            <Form.Item
              name="loginName"
              label="登录名称"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="请输入登录名称" />
            </Form.Item>
            <Form.Item
              name="userName"
              label="用户姓名"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="请输入用户姓名" />
            </Form.Item>
            <Form.Item name="phone" label="手机号码">
              <Input placeholder="请输入手机号码" />
            </Form.Item>
            <Form.Item name="email" label="电子邮箱">
              <Input placeholder="请输入电子邮箱" />
            </Form.Item>
          </Form>
        </Modal>
        <Modal
          title="请确认"
          visible={freezeUserVisible}
          onOk={submitFreezeUser}
          onCancel={() => setFreezeUserVisible(false)}
          okText="确认"
          cancelText="取消"
        >
          <p>
            即将{+currentUser.state ? '激活' : '冻结'}用户{' '}
            <span className={styles.redText}>{currentUser.loginName}</span>
            ，是否确认
            {+currentUser.state ? '激活' : '冻结'}？
          </p>
        </Modal>
        <Modal
          title="确认删除用户"
          visible={deleteUserVisible}
          onOk={submitDeleteUser}
          onCancel={() => setDeleteUserVisible(false)}
          okText="确认"
          cancelText="取消"
        >
          <p>
            将删除用户
            <span className={styles.redText}>{currentUser.loginName}</span>,
            是否确认删除？
          </p>
        </Modal>
      </div>
    </PageContainer>
  );
};

export default UserManage;
