import React, { useState, useEffect } from 'react';
import {
  Row,
  Col,
  Card,
  Input,
  Tooltip,
  Button,
  notification,
  Spin,
  List,
  Space,
} from 'antd';
import { FileAddTwoTone, EditTwoTone, DeleteTwoTone } from '@ant-design/icons';
import { PageContainer, GridContent } from '@ant-design/pro-layout';
import {
  getWebModuleTree,
  chooseUserToStation,
} from '@/services/userCenter/siteManage/api';
import ListCard from '@/pages/orgnazation/ListCard';
import styles from '@/pages/userCenter/siteManage/SiteManage.less';
import qs from 'qs';
import classnames from 'classnames';
import AddModal from './AddModal';
import DelModal from './DelModal';
import EditModal from './EditModal';

const { Search } = Input;
const placeholder = '请输入人员姓名';
const SiteManage = () => {
  const [treeData, setTreeData] = useState([]); // 树结构数据
  const [currentStation, setCurrentStation] = useState({}); // 当前选中站点
  const [searchWord, setSearchWord] = useState(''); // 关键字
  const [modalVisible, setModalVisible] = useState(false); // 新增弹窗
  const [flag, setFlag] = useState(1);
  const [delVisible, setDelVisible] = useState(false); // 删除弹窗
  const [editVisible, setEditVisible] = useState(false); // 修改弹窗
  const [subList, setSubList] = useState([]); // 选中的数组
  const [spinLoading, setSpinLoading] = useState(false);
  const now = new Date().getTime();

  useEffect(() => {
    setSpinLoading(true);
    getWebModuleTree({
      userMode: 'super',
      select: '',
      _version: 9999,
      _dc: now,
      node: -2,
    })
      .then(res => {
        setSpinLoading(false);
        let arr = [];
        if (res) {
          arr.push(res.find(item => item.id === 'Web4StationRoot'));
        }
        if (arr[0]) {
          const stations = arr[0].children;
          setTreeData(stations);
          if (!currentStation.stationID) {
            setCurrentStation(stations[0]);
          } else {
            setCurrentStation(
              stations.find(s => s.stationID === currentStation.stationID) ||
                stations[0],
            );
          }
        }
      })
      .catch(err => {
        setSpinLoading(false);
        console.error(err);
      });
  }, [flag]);

  const Title = props => {
    const { text } = props;
    return (
      <div className={styles.treeTitle}>
        {text}
        <div className={styles.titleBox}>
          <Tooltip title="新增站点">
            <FileAddTwoTone
              onClick={() => {
                handleAdd(props);
              }}
            />
          </Tooltip>
          <Tooltip title="编辑站点">
            <EditTwoTone
              onClick={() => {
                handleEdit(props);
              }}
            />
          </Tooltip>
          <Tooltip title="删除站点">
            <DeleteTwoTone
              onClick={() => {
                handleDel(props);
              }}
            />
          </Tooltip>
        </div>
      </div>
    );
  };
  const handleAdd = e => {
    console.log(e);
    setModalVisible(true);
  };
  // 站点删除
  const handleDel = e => {
    setDelVisible(true);
  };
  // 编辑站点
  const handleEdit = e => {
    setEditVisible(true);
  };
  // 树形数据转换
  const transTree = val => {
    let arr = val;
    return arr.map((item, index) => {
      item.title = Title(item) || item.text;
      item.key = item.stationID || '';
      let obj = {};
      if (Array.isArray(item.children) && item.children.length > 0) {
        transTree(item.children);
        obj = item;
        return obj;
      }
      return item;
    });
  };
  // 获取搜索框的值
  const handleSearch = value => {
    setSearchWord(value);
  };
  const handleChange = e => {
    const { value } = e.target;
    setSearchWord(value);
  };
  const confirmModal = e => {
    setModalVisible(false);
    setFlag(flag + 1);
  };
  const delModal = () => {
    setDelVisible(false);
    setFlag(flag + 1);
  };
  const editModal = () => {
    setEditVisible(false);
    setFlag(flag + 1);
  };
  const valueCallback = valueObj => {
    setSubList(valueObj);
  };
  const handleCommit = value => {
    let arr = Object.values(subList);
    chooseUserToStation(
      qs.stringify({
        userList: String(arr.flat()),
        stationID: currentStation.stationID,
      }),
      {
        headers: {
          'content-type': 'application/x-www-form-urlencggoded;charset=UTF-8',
        },
      },
    )
      .then(res => {
        if (res.success) {
          notification.success({
            message: '提示',
            duration: 3,
            description: '设置成功',
          });
        } else {
          notification.error({
            message: '提示',
            duration: 3,
            description: res.message,
          });
        }
      })
      .catch(err => {
        console.log(err);
      });
  };

  const renderListItem = items =>
    items.map(t => (
      <List.Item
        onClick={() => {
          setCurrentStation(t);
        }}
        key={t.id}
        className={classnames({
          [styles.listItem]: true,
          [styles.selected]: currentStation.id === t.id,
        })}
      >
        {t.text}
      </List.Item>
    ));

  return (
    <PageContainer>
      <GridContent>
        <Row gutter={12}>
          <Col lg={6}>
            <Card className={styles.cardBox}>
              <Spin
                tip="loading...."
                spinning={spinLoading}
                style={{ marginTop: '20px' }}
              >
                <List>{renderListItem(treeData)}</List>
              </Spin>
              <AddModal
                visible={modalVisible}
                onCancel={() => setModalVisible(false)}
                confirmModal={confirmModal}
              />
              <DelModal
                visible={delVisible}
                stationId={currentStation.stationID}
                onCancel={() => setDelVisible(false)}
                confirmModal={delModal}
              />
              <EditModal
                visible={editVisible}
                stationObj={currentStation}
                onCancel={() => setEditVisible(false)}
                confirmModal={editModal}
              />
            </Card>
          </Col>
          <Col lg={18}>
            <Card style={{ marginBottom: '10px' }}>
              <Row align="middle">
                <Col span={1}>搜索</Col>
                <Col span={8}>
                  <Search
                    allowClear
                    placeholder={placeholder}
                    onSearch={handleSearch}
                    onChange={handleChange}
                    enterButton
                  />
                </Col>
                <Col span={3} />
                <Col span={8}>
                  <Space>
                    <Button
                      type="primary"
                      onClick={() => {
                        handleAdd();
                      }}
                    >
                      新增
                    </Button>
                    <Button
                      type="primary"
                      onClick={() => {
                        handleEdit();
                      }}
                      disabled={!currentStation.stationID || spinLoading}
                    >
                      编辑
                    </Button>
                    <Button
                      danger
                      onClick={() => {
                        handleDel(currentStation.stationID);
                      }}
                      disabled={!currentStation.stationID || spinLoading}
                    >
                      删除
                    </Button>
                  </Space>
                </Col>
              </Row>
            </Card>
            <Card className={styles.cardBoxR}>
              {currentStation.stationID && (
                <ListCard
                  ouid={currentStation.stationID}
                  searchWord={searchWord}
                  valueCallback={valueCallback}
                  onCommit={handleCommit}
                />
              )}
            </Card>
          </Col>
        </Row>
      </GridContent>
    </PageContainer>
  );
};

export default SiteManage;
