import React from 'react';
import { Button, Col, Drawer, Row } from 'antd';
import styles from './siteConfigDrawer.less';
import BaseForm, { ITEM_TYPE } from '@/components/BaseForm';
let form = null;
const typeContent = hasIntegerate => {
  if (hasIntegerate) {
    return [];
  }
  return [
    {
      value: 'a',
      children: '集成网站',
    },
  ];
};

const defaultKeyMap = ({ hasIntegerate }) => ({
  title: {
    label: '标题',
    formType: ITEM_TYPE.INPUT,
    allowClear: true,
    placeholder: '请输入标题',
    rules: [
      {
        required: true,
        message: '标题为必填项',
      },
    ],
  },
  subtitle: {
    label: '副标题',
    formType: ITEM_TYPE.INPUT,
    allowClear: true,
  },
  type: {
    label: '网站类型',
    formType: ITEM_TYPE.SINGLE_RADIO,
    initialValue: hasIntegerate ? 'b' : 'a',
    options: [
      {
        value: 'b',
        children: '一般网站',
      },
    ].concat(typeContent(hasIntegerate)),
  },
  shortcutIcon: {
    label: '图标icon',
    formType: ITEM_TYPE.IMGSHOP,
    rules: [
      {
        required: true,
        message: '请选择图标icon',
      },
    ],
  },
  logo: {
    label: '登录logo',
    formType: ITEM_TYPE.IMGSHOP,
    rules: [
      {
        required: true,
        message: '请选择登录logo',
      },
    ],
  },
  bannerlogo: {
    label: '标题logo',
    formType: ITEM_TYPE.IMGSHOP,
    rules: [
      {
        required: true,
        message: '请选择标题logo',
      },
    ],
  },
  client: {
    label: '虚拟目录',
    formType: ITEM_TYPE.INPUT,
    allowClear: true,
    size: 'small',
    rules: [
      {
        required: true,
        message: '虚拟目录不能为空',
      },
    ],
  },
  homePage: {
    label: '主页',
    formType: ITEM_TYPE.INPUT,
    allowClear: true,
  },
  loginTemplate: {
    label: '登录模板',
    formType: ITEM_TYPE.SELECT,
    placeholder: '请选择登录模板',
    options: [
      {
        value: 'a',
        children: 'default.html',
      },
      {
        value: 'b',
        children: 'dark.html',
      },
    ],
    showSearch: true,
    filterOption: (input, option) =>
      option.children.toLowerCase().indexOf(input.toLowerCase()) >= 0,
    rules: [
      {
        required: true,
        message: '登录模板必填',
      },
    ],
  },
  theme: {
    label: '系统皮肤',
    formType: ITEM_TYPE.SINGLE_RADIO,
    initialValue: 'a',
    options: [
      {
        value: 'a',
        children: 'a',
      },
      {
        value: 'b',
        children: 'b',
      },
    ],
    rules: [
      {
        required: true,
        message: '请选择系统皮肤',
      },
    ],
  },
  // style: '系统风格',
  // menu: '菜单类型',
  // mode: '功能标签',
  // qrcode: '二维码地址',
  // mapPlan: '地图方案',
  // waterMark: '地图水印',
});

export default props => {
  const { visible, onClose, config, hasIntegerate = true } = props;

  const getForm = f => {
    form = f;
  };
  const itemsMap = defaultKeyMap({ hasIntegerate });
  const formConfig = {
    getForm,
    items: Object.keys(itemsMap).map(k => ({
      ...itemsMap[k],
      dataIndex: k,
    })),
    buttons: [
      {
        text: '取消',
        type: 'cancel',
        onClick: () => {
          // eslint-disable-next-line no-unused-expressions
          onClose && onClose();
        },
      },
      {
        text: '确定',
        htmlType: 'submit',
        type: 'primary',
        style: {
          marginLeft: '10px',
        },
      },
    ],
    buttonsWraper: bts => (
      <Row>
        <Col span={24} style={{ textAlign: 'right' }}>
          {bts}
        </Col>
      </Row>
    ),
  };
  return (
    <div className={styles.siteConfigContainer}>
      <Drawer
        title="添加网站"
        width={520}
        closable
        onClose={onClose}
        visible={visible}
        maskClosable={false}
      >
        <BaseForm {...formConfig} />
      </Drawer>
    </div>
  );
};
